pub struct Disc { /* private fields */ }Expand description
An open disc image and read stream.
This is the primary entry point for reading disc images.
Implementations
sourceimpl Disc
impl Disc
sourcepub fn new_with_options<P: AsRef<Path>>(
path: P,
options: &OpenOptions
) -> Result<Disc>
pub fn new_with_options<P: AsRef<Path>>( path: P, options: &OpenOptions ) -> Result<Disc>
Opens a disc image from a file path with custom options.
sourcepub fn header(&self) -> &DiscHeader
pub fn header(&self) -> &DiscHeader
The disc’s primary header.
sourcepub fn meta(&self) -> DiscMeta
pub fn meta(&self) -> DiscMeta
Returns extra metadata included in the disc file format, if any.
sourcepub fn disc_size(&self) -> u64
pub fn disc_size(&self) -> u64
The disc’s size in bytes, or an estimate if not stored by the format.
sourcepub fn partitions(&self) -> &[PartitionInfo]
pub fn partitions(&self) -> &[PartitionInfo]
A list of Wii partitions on the disc.
GameCube: This will return an empty slice.
sourcepub fn open_partition(&self, index: usize) -> Result<Box<dyn PartitionBase>>
pub fn open_partition(&self, index: usize) -> Result<Box<dyn PartitionBase>>
Opens a decrypted partition read stream for the specified partition index.
GameCube: index must always be 0.
sourcepub fn open_partition_kind(
&self,
kind: PartitionKind
) -> Result<Box<dyn PartitionBase>>
pub fn open_partition_kind( &self, kind: PartitionKind ) -> Result<Box<dyn PartitionBase>>
Opens a decrypted partition read stream for the first partition matching the specified kind.
GameCube: kind must always be PartitionKind::Data.